@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 #--------------------------------------------------------------------------
 
@@ -96,7 +96,7 @@ sub search {
 
 	eval { $mech->get( $search ) };
     return $self->handler("Amazon UK website appears to be unavailable.")
-	    unless($@ || $mech->success());
+	    if($@ || !$mech->success() || !$mech->content());
 
 	my $content = $mech->content();
     my ($link) = $content =~ m!($AMA_URL)!s;
@@ -105,7 +105,7 @@ sub search {
 
 	eval { $mech->get( $link ) };
     return $self->handler("Amazon UK website appears to be unavailable.")
-	    unless($@ || $mech->success());
+	    if($@ || !$mech->success() || !$mech->content());
 
 	# The Book page
     my $html = $mech->content;
@@ -136,6 +136,9 @@ sub search {
     $data->{width}  = int($data->{width} * 10)  if($data->{width});
     $data->{height} = int($data->{height} * 10) if($data->{height});
 
+	return $self->handler("Could not extract data from Amazon UK result page.")
+		unless(defined $data->{isbn13});
+
     # trim top and tail
 	foreach (keys %$data) { next unless(defined $data->{$_});$data->{$_} =~ s/^\s+//;$data->{$_} =~ s/\s+$//; }
 
